@@ -1,9 +1,13 @@
+import logging
+import os
+import sys
 from typing import Optional
 
 import rosys
-from rosys.event import Event
+from nicegui import ui
 
-from .communication import Communication
+from ..event import Event
+from .communication import Communication, SerialCommunication
 
 
 class RobotBrain:
@@ -13,19 +17,23 @@ class RobotBrain:
     Besides providing some basic methods like configuring or restarting the microcontroller, it augments and verifies checksums for each message.
     '''
 
-    def __init__(self, communication: Communication) -> None:
+    def __init__(self, communication: Communication, lizard_startup: str = 'lizard.txt') -> None:
         self.LINE_RECEIVED = Event()
         '''a line has been received from the microcontroller (argument: line as string)'''
 
         self.communication = communication
+        self.lizard_startup = lizard_startup
         self.waiting_list: dict[str, Optional[str]] = {}
 
         self.clock_offset: Optional[float] = None
         self.hardware_time: Optional[float] = None
+        self.flash_params: list[str] = []
+        self.log = logging.getLogger('rosys.robot_rain')
 
-    async def configure(self, filepath: str = 'lizard.txt') -> None:
+    async def configure(self) -> None:
+        self.log.info('Configuring...')
         await self.send(f'!-')
-        with open(filepath) as f:
+        with open(self.lizard_startup) as f:
             for line in f.read().splitlines():
                 await self.send(f'!+{line}')
         await self.send(f'!.')
@@ -70,6 +78,41 @@ class RobotBrain:
             await rosys.sleep(0.1)
         return self.waiting_list.pop(ack) if ack in self.waiting_list else None
 
+    async def flash(self) -> None:
+        with ui.dialog() as dialog, ui.card():
+            status = ui.markdown('.... flashing ....')
+        dialog.open()
+        # NOTE this is a workaround for a bug in the current version of NiceGUI, see https://github.com/zauberzeug/nicegui/issues/131
+        rosys.task_logger.create_task(dialog.page.update())
+        assert isinstance(self.communication, SerialCommunication)
+        self.communication.disconnect()
+        output = await rosys.run.sh(['./flash.py'] + self.flash_params, timeout=None, working_dir=os.path.expanduser('~/.lizard'))
+        status.set_content(f'```\n{output}\n```')
+        self.communication.connect()
+
+    def developer_ui(self) -> None:
+        ui.label('Lizard')
+        ui.button('Configure', on_click=self.configure).props('outline')
+        ui.button('Restart', on_click=self.restart).props('outline')
+        ui.button('Flash', on_click=self.flash).props('outline')
+        ui.button('Enable', on_click=self.enable_esp).props('outline')
+
+    def enable_esp(self) -> None:
+        try:
+            sys.path.insert(1, os.path.expanduser('~/.lizard'))
+            from esp import Esp
+            esp = Esp()
+            with esp.pin_config():
+                esp.activate()
+        except:
+            self.log.exception('Could not enable ESP')
+
+    def __del__(self) -> None:
+        self.communication.disconnect()
+
+    def __repr__(self) -> str:
+        return f'<RobotBrain {self.communication}>'
+
 
 def augment(line: str) -> str:
     checksum = 0
