@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
-from nicegui import ui
 import pylab as pl
-import rosys.pathplanning.plot_tools as pt
+from nicegui import ui
+from rosys.pathplanning import plot_tools as pt
 from rosys.pathplanning.experiments import generate_experiment
 
-robot_renderer, pose, goal, obstacle_map, small_obstacle_map, backward_to_goal = generate_experiment(5.0)
+robot_renderer, pose, goal, obstacle_map, backward_to_goal = generate_experiment(5.0)
 
 with ui.plot():
     pt.show_obstacle_map(obstacle_map)
