@@ -1,15 +1,22 @@
+from __future__ import annotations
+
+import time
+from typing import Optional
+
+import cv2
 import numpy as np
 from scipy import ndimage
-import cv2
-from ..world import World
+
+from .area import Area
 from .binary_renderer import BinaryRenderer
 from .grid import Grid
+from .obstacle import Obstacle
 from .robot_renderer import RobotRenderer
 
 
 class ObstacleMap:
 
-    def __init__(self, grid, map_, robot_renderer):
+    def __init__(self, grid, map_, robot_renderer, deadline=None) -> None:
         self.grid = grid
         self.map = map_
         self.stack = np.zeros(grid.size, dtype=bool)
@@ -20,13 +27,15 @@ class ObstacleMap:
             self.stack[:, :, layer] = cv2.dilate(self.map.astype(np.uint8), kernel)
             self.dist_stack[:, :, layer] = \
                 ndimage.distance_transform_edt(~self.stack[:, :, layer]) * grid.pixel_size
+            if deadline and time.time() > deadline:
+                raise TimeoutError('obstacle map creation took too long')
 
         # NOTE: when yaw wraps around, map_coordinates should wrap around on axis 2
         self.stack = np.dstack((self.stack, self.stack[:, :, :1]))
         self.dist_stack = np.dstack((self.dist_stack, self.dist_stack[:, :, :1]))
 
     @staticmethod
-    def from_list(grid, obstacles, robot_renderer):
+    def from_list(grid, obstacles, robot_renderer) -> ObstacleMap:
         map_ = np.zeros(grid.size[:2], dtype=bool)
         for x, y, w, h in obstacles:
             r0, c0 = grid.to_grid(x, y)
@@ -36,15 +45,23 @@ class ObstacleMap:
         return ObstacleMap(grid, map_, robot_renderer)
 
     @staticmethod
-    def from_world(world: World, grid: Grid):
-        robot_renderer = RobotRenderer(world.robot.shape.outline)
-        has_areas = any(len(a.outline) > 2 for a in world.areas.values())
+    def from_world(robot_outline: list[tuple[float, float]],
+                   areas: list[Area],
+                   obstacles: list[Obstacle],
+                   grid: Grid,
+                   deadline: Optional[float] = None) -> ObstacleMap:
+        robot_renderer = RobotRenderer(robot_outline)
+        has_areas = any(len(a.outline) > 2 for a in areas)
         binary_renderer = BinaryRenderer(grid.size[:2], fill_value=has_areas)
-        for area in world.areas.values():
+        for area in areas:
             binary_renderer.polygon(np.array([grid.to_grid(p.x, p.y)[::-1] for p in area.outline]), False)
-        for obstacle in world.obstacles.values():
+            if deadline and time.time() > deadline:
+                raise TimeoutError('obstacle map creation took too long')
+        for obstacle in obstacles:
             binary_renderer.polygon(np.array([grid.to_grid(p.x, p.y)[::-1] for p in obstacle.outline]))
-        return ObstacleMap(grid, binary_renderer.map, robot_renderer)
+            if deadline and time.time() > deadline:
+                raise TimeoutError('obstacle map creation took too long')
+        return ObstacleMap(grid, binary_renderer.map, robot_renderer, deadline)
 
     def test(self, x, y, yaw):
         row, col, layer = self.grid.to_grid(x, y, yaw)
@@ -52,7 +69,7 @@ class ObstacleMap:
 
     t_lookup = [np.linspace(0, 1, i) for i in range(360)]
 
-    def _create_poses(self, spline, backward):
+    def _create_poses(self, spline, backward) -> tuple:
         def pose(t): return (
             spline.x(t),
             spline.y(t),
@@ -67,12 +84,12 @@ class ObstacleMap:
         t = ObstacleMap.t_lookup[n] if n < len(ObstacleMap.t_lookup) else np.linspace(0, 1, n)
         return pose(t)
 
-    def test_spline(self, spline, backward=False):
+    def test_spline(self, spline, backward=False) -> bool:
         return self.test(*self._create_poses(spline, backward)).any()
 
-    def get_distance(self, x, y, yaw):
+    def get_distance(self, x, y, yaw) -> np.ndarray:
         row, col, layer = self.grid.to_grid(x, y, yaw)
         return ndimage.map_coordinates(self.dist_stack, [[row], [col], [layer]], order=0)
 
-    def get_minimum_spline_distance(self, spline, backward=False):
+    def get_minimum_spline_distance(self, spline, backward=False) -> float:
         return self.get_distance(*self._create_poses(spline, backward)).min()
